summaryrefslogtreecommitdiff
path: root/include/internal/database/xaxpy.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/internal/database/xaxpy.h')
-rw-r--r--include/internal/database/xaxpy.h107
1 files changed, 39 insertions, 68 deletions
diff --git a/include/internal/database/xaxpy.h b/include/internal/database/xaxpy.h
index 058e3c0a..783e142d 100644
--- a/include/internal/database/xaxpy.h
+++ b/include/internal/database/xaxpy.h
@@ -5,9 +5,9 @@
// width of 100 characters per line.
//
// Author(s):
-// Cedric Nugteren <www.cedricnugteren.nl>
+// Database generator <database.py>
//
-// This file populates the database with best-found tuning parameters for the Xaxpy kernels.
+// This file populates the database with best-found tuning parameters for the 'Xaxpy' kernels.
//
// =================================================================================================
@@ -16,26 +16,21 @@ namespace clblast {
const Database::DatabaseEntry Database::XaxpySingle = {
"Xaxpy", Precision::kSingle, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"WGS",128}, {"WPT",1}, {"VW",2} } },
- { "Tesla K20m", { {"WGS",128}, {"WPT",2}, {"VW",2} } },
- { "Tesla K40m", { {"WGS",128}, {"WPT",1}, {"VW",4} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"WGS",64}, {"WPT",1}, {"VW",2} } },
+ { // Intel GPUs
+ kDeviceTypeGPU, "Intel", {
+ { "Iris", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
+ { "default", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
}
},
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
- { "Iris", { {"WGS",512}, {"WPT",1}, {"VW",1} } },
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"VW",4}, {"WGS",128}, {"WPT",1} } },
+ { "default", { {"VW",4}, {"WGS",128}, {"WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"WGS",128}, {"WPT",1}, {"VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
}
},
}
@@ -43,55 +38,41 @@ const Database::DatabaseEntry Database::XaxpySingle = {
// =================================================================================================
-const Database::DatabaseEntry Database::XaxpyDouble = {
- "Xaxpy", Precision::kDouble, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"WGS",128}, {"WPT",1}, {"VW",1} } },
- { "Tesla K20m", { {"WGS",512}, {"WPT",1}, {"VW",2} } },
- { "Tesla K40m", { {"WGS",64}, {"WPT",1}, {"VW",2} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"WGS",256}, {"WPT",1}, {"VW",1} } },
+const Database::DatabaseEntry Database::XaxpyComplexSingle = {
+ "Xaxpy", Precision::kComplexSingle, {
+ { // Intel GPUs
+ kDeviceTypeGPU, "Intel", {
+ { "Iris", { {"VW",2}, {"WGS",128}, {"WPT",1} } },
+ { "default", { {"VW",2}, {"WGS",128}, {"WPT",1} } },
}
},
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"VW",1}, {"WGS",128}, {"WPT",1} } },
+ { "default", { {"VW",1}, {"WGS",128}, {"WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"WGS",128}, {"WPT",1}, {"VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"VW",1}, {"WGS",128}, {"WPT",1} } },
}
},
}
};
+
// =================================================================================================
-const Database::DatabaseEntry Database::XaxpyComplexSingle = {
- "Xaxpy", Precision::kComplexSingle, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"WGS",256}, {"WPT",1}, {"VW",1} } },
- { "Tesla K20m", { {"WGS",128}, {"WPT",1}, {"VW",1} } },
- { "Tesla K40m", { {"WGS",128}, {"WPT",2}, {"VW",1} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"WGS",64}, {"WPT",1}, {"VW",1} } },
- }
- },
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
- { "Iris", { {"WGS",256}, {"WPT",1}, {"VW",1} } },
+const Database::DatabaseEntry Database::XaxpyDouble = {
+ "Xaxpy", Precision::kDouble, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"VW",2}, {"WGS",128}, {"WPT",1} } },
+ { "default", { {"VW",2}, {"WGS",128}, {"WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"WGS",128}, {"WPT",1}, {"VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"VW",2}, {"WGS",128}, {"WPT",1} } },
}
},
}
@@ -101,25 +82,15 @@ const Database::DatabaseEntry Database::XaxpyComplexSingle = {
const Database::DatabaseEntry Database::XaxpyComplexDouble = {
"Xaxpy", Precision::kComplexDouble, {
- { // NVIDIA GPUs
- kDeviceTypeGPU, kDeviceVendorNVIDIA, {
- { "GeForce GTX 480", { {"WGS",128}, {"WPT",2}, {"VW",1} } },
- { "Tesla K20m", { {"WGS",256}, {"WPT",1}, {"VW",1} } },
- { "Tesla K40m", { {"WGS",64}, {"WPT",2}, {"VW",1} } },
- }
- },
- { // AMD GPUs
- kDeviceTypeGPU, kDeviceVendorAMD, {
- { "Tahiti", { {"WGS",64}, {"WPT",1}, {"VW",1} } },
- }
- },
- { // Intel GPUs
- kDeviceTypeGPU, kDeviceVendorIntel, {
+ { // NVIDIA Corporation GPUs
+ kDeviceTypeGPU, "NVIDIA Corporation", {
+ { "Tesla K40m", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
+ { "default", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
}
},
{ // Default
- kDeviceTypeAll, kDeviceVendorAll, {
- { kDefaultDevice, { {"WGS",128}, {"WPT",1}, {"VW",1} } },
+ kDeviceTypeAll, "default", {
+ { "default", { {"VW",1}, {"WGS",64}, {"WPT",1} } },
}
},
}